@@ -4,7 +4,7 @@ from deezer.gw import GW
 from deezer.api import API
 from deezer.errors import DeezerError, WrongLicense, WrongGeolocation
 
-__version__ = "1.2.3"
+__version__ = "1.2.4"
 
 class TrackFormats():
     """Number associtation for formats"""
@@ -183,7 +183,7 @@ class Deezer:
                         result.append(WrongGeolocation(self.current_user['country']))
                     else:
                         result.append(DeezerError(json.dumps(response)))
-                if data['media']:
+                if 'media' in data:
                     result.append(data['media'][0]['sources'][0]['url'])
                 else:
                     result.append(None)
